@@ -164,6 +164,9 @@ let options = Arg.align [
   ( "-generate_aux_rules",
     Arg.Bool (fun b -> generate_aux_rules := b),
     "<"^string_of_bool !generate_aux_rules^">  Generate auxiliary rules from {{ aux ... }} homs" );
+  ( "-output_source_locations",
+    Arg.Int (fun i -> Global_option.output_source_locations := i),
+    "<"^string_of_int !Global_option.output_source_locations^">  Include source location info in output (0=none, 1=drules, 2=grammar+drules)" );
 
 (* options for ascii output *)
   ( "-colour", 
@@ -371,8 +374,7 @@ let source_filenames =
     | Out,_,_ -> None) 
     all_file_arguments
 
-(* let _ = print_string ("source_filenames = 
-   "^String.concat ", " (List.map (function (t,n) -> n^":"^t) source_filenames)^"\n") *)
+let _ = if false then print_string ("source_filenames =   "^String.concat ", " (List.map (function (t,n) -> n^":"^t) source_filenames)^"\n")
 
 (* pp modes, used both for main output and for filtered files *)
 let m_ascii = Ascii { ppa_colour = !colour; 
@@ -429,7 +431,7 @@ let m_yacc = Yacc ()
    and isa, for the non-picky checking, but now we feed dummy filenames
    into the m_... functions *)
 
-let _ =
+   let _ =
   Global_option.is_picky := 
     ( !picky_multiple_parses,
       List.map 
@@ -444,7 +446,7 @@ let _ =
         targets_for_non_picky)
 
 (* process *)
-
+   
 let process source_filenames = 
   let sources = String.concat " " (List.map snd source_filenames) in
 
@@ -482,9 +484,9 @@ let process source_filenames =
     | "ott" -> 
         let c = open_in filename in
         let lexbuf = Lexing.from_channel c in
-        if List.length source_filenames <> 1 then 
-          lexbuf.Lexing.lex_curr_p <- 
-            { lexbuf.Lexing.lex_curr_p with Lexing.pos_fname = filename};
+        (*if List.length source_filenames <> 1 then *)
+        lexbuf.Lexing.lex_curr_p <- 
+          { lexbuf.Lexing.lex_curr_p with Lexing.pos_fname = filename};
         let ris = 
           (try
             Grammar_parser.main (Grammar_lexer.my_lexer true Grammar_lexer.metalang) lexbuf
